@@ -26,17 +26,24 @@
 function(X, Z, XX=NULL, bprior="bflat", corr="expsep",
          BTE=c(1000,4000,2), R=1, m0r1=FALSE,
          pred.n=TRUE, ds2x=FALSE, ego=FALSE, nu=0.5,
-         verb=1)
+         traces=FALSE, verb=1)##, 
+	 ##base="gp", mrd.p =c(1,100,1,20), delta.p=c(2,2,2,2), nugf.p=c(1,20,1,1))
 {
   n <- dim(X)[1]
   if(is.null(n)) { n <- length(X); X <- matrix(X, nrow=n); d <- 1 }
   else { d <- dim(X)[2] }
+  ##params <- tgp.default.params(d+1, base=base)
   params <- tgp.default.params(d+1)
   params$bprior <- bprior
   params$corr <- corr
   params$tree <- c(0,0,10)	# no tree
   params$gamma <- c(0,0.2,0.7)	# no llm
+  ##if(base=="mrgp"){
+	 ##params$d.p <- c(params$d.p,mrd.p)
+	 ##params$delta.p <- delta.p
+	 ##params$nugf.p <- nugf.p
+	##} 
   if(corr == "matern") params$nu <- nu
-  return(tgp(X,Z,XX,BTE,R,m0r1,FALSE,params,pred.n,ds2x,ego,verb))
+  return(tgp(X,Z,XX,BTE,R,m0r1,FALSE,params,pred.n,ds2x,ego,traces,verb))
 }
 
