@@ -43,6 +43,7 @@ class Gp : public Base
 
   double **F;		        /* col x n, matrix (1,X) */
   double **FF;		        /* col x nn, matrix (1,XX) */
+  unsigned int col;	        
 
   double **xxKx;		/* nn x n, cross covariance between XX and X */
   double **xxKxx;		/* nn x nn, cross covariance between XX and XX */
@@ -68,8 +69,8 @@ class Gp : public Base
   virtual Base* Dup(double **X, double *Z); 
   virtual void Clear(void);
   virtual void ClearPred(void);
-  virtual void Update(double **X, unsigned int n, unsigned int col, double *Z);
-  virtual void UpdatePred(double **XX, unsigned int nn, unsigned int col, 
+  virtual void Update(double **X, unsigned int n, unsigned int d, double *Z);
+  virtual void UpdatePred(double **XX, unsigned int nn, unsigned int d, 
 			  double **Ds2xy);  
   virtual bool Draw(void *state);
   virtual void Predict(unsigned int n, unsigned int nn, double *z, double *zz, 
@@ -87,6 +88,8 @@ class Gp : public Base
   virtual char* State(void);
   virtual unsigned int sum_b(void);
   virtual void Init(void);
+  virtual void X_to_F(unsigned int n, double **X, double **F);
+  virtual double* Trace(unsigned int* len);
 
   double* get_b(void);
   double *Bmle(void);
@@ -104,6 +107,7 @@ class Gp_Prior : public Base_Prior
 
   BETA_PRIOR beta_prior;	/* indicator for type of Beta Prior */  
   Corr_Prior *corr_prior;
+  unsigned int col;		
 
   double *b;		        /* col, regression coefficients */
   double s2;		        /* variance parameter */
@@ -136,7 +140,7 @@ class Gp_Prior : public Base_Prior
  public:
   
   /* start public functions */
-  Gp_Prior(unsigned int col);
+  Gp_Prior(unsigned int d);
   Gp_Prior(Base_Prior* prior);
   virtual ~Gp_Prior(void);
 
