@@ -29,6 +29,12 @@ int predict_full(unsigned int n1, unsigned int n2, unsigned int col, double *z,
 		 double **Ds2xy, double *ego, double *Z, double **F, double **K, double **Ki, 
 		 double **W, double tau2, double **FF, double **xxKx, double ** xxKxx, double *b, 
 		 double ss2, double nug, int err, void *state);
+int mr_predict_full(unsigned int n1, unsigned int n2, unsigned int col, double *z, double *zz, 
+		    double **Ds2xy, double *ego, 
+		    double *Z, double **X, double **F, double **K, double **Ki, 
+		    double **W, double tau2, double **XX, double **FF, double **xxKx,
+		    double ** xxKxx, double *b,  double ss2, double nug, double nugfine,
+		    double r, double delta, int err, void *state);
 void delta_sigma2(double *Ds2xy, unsigned int n1, unsigned int n2, unsigned int col, 
 	double ss2, double denom, double **FW, double tau2, double *fW, double *KpFWFiQx, 
 	double **FFrow, double **KKrow, double **xxKxx, unsigned int which_i);
